/*
 * Copyright 2007-2017 Charles du Jeu - Abstrium SAS <team (at) pyd.io>
 * This file is part of Pydio.
 *
 * Pydio is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Pydio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Pydio.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The latest code can be found at <https://pydio.com>.
 */

'use strict';

exports.__esModule = true;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _color = require('color');

var _color2 = _interopRequireDefault(_color);

var React = require('react');

var _require = require('material-ui/styles');

var muiThemeable = _require.muiThemeable;

var Pydio = require('pydio');
var PydioApi = require('pydio/http/api');
var Node = require('pydio/model/node');

var _Pydio$requireLib = Pydio.requireLib('components');

var FoldersTree = _Pydio$requireLib.FoldersTree;

var _Pydio$requireLib2 = Pydio.requireLib('hoc');

var withContextMenu = _Pydio$requireLib2.withContextMenu;

var Confirm = React.createClass({
    displayName: 'Confirm',

    propTypes: {
        pydio: React.PropTypes.instanceOf(Pydio),
        onDecline: React.PropTypes.func,
        onAccept: React.PropTypes.func,
        mode: React.PropTypes.oneOf(['new_share', 'reject_accepted'])
    },

    componentDidMount: function componentDidMount() {
        this.refs.dialog.show();
    },

    render: function render() {
        var messages = this.props.pydio.MessageHash,
            messageTitle = messages[545],
            messageBody = messages[546],
            actions = [{ text: messages[548], ref: 'decline', onClick: this.props.onDecline }, { text: messages[547], ref: 'accept', onClick: this.props.onAccept }];
        if (this.props.mode == 'reject_accepted') {
            messageBody = messages[549];
            actions = [{ text: messages[54], ref: 'decline', onClick: this.props.onDecline }, { text: messages[551], ref: 'accept', onClick: this.props.onAccept }];
        }

        for (var key in this.props.replacements) {
            messageTitle = messageTitle.replace(new RegExp(key), this.props.replacements[key]);
            messageBody = messageBody.replace(new RegExp(key), this.props.replacements[key]);
        }

        return React.createElement(
            'div',
            { className: 'react-mui-context', style: { position: 'fixed', top: 0, left: 0, width: '100%', height: '100%', background: 'transparent' } },
            React.createElement(
                ReactMUI.Dialog,
                {
                    ref: 'dialog',
                    title: messageTitle,
                    actions: actions,
                    modal: false,
                    dismissOnClickAway: true,
                    onDismiss: this.props.onDismiss.bind(this),
                    open: true
                },
                messageBody
            )
        );
    }
});

var WorkspaceEntry = React.createClass({
    displayName: 'WorkspaceEntry',

    propTypes: {
        pydio: React.PropTypes.instanceOf(Pydio).isRequired,
        workspace: React.PropTypes.instanceOf(Repository).isRequired,
        showFoldersTree: React.PropTypes.bool,
        onHoverLink: React.PropTypes.func,
        onOutLink: React.PropTypes.func
    },

    getInitialState: function getInitialState() {
        return {
            openAlert: false,
            openFoldersTree: false,
            currentContextNode: this.props.pydio.getContextHolder().getContextNode()
        };
    },

    getLetterBadge: function getLetterBadge() {
        return { __html: this.props.workspace.getHtmlBadge(true) };
    },

    componentDidMount: function componentDidMount() {
        if (this.props.showFoldersTree) {
            this._monitorFolder = (function () {
                this.setState({ currentContextNode: this.props.pydio.getContextHolder().getContextNode() });
            }).bind(this);
            this.props.pydio.getContextHolder().observe("context_changed", this._monitorFolder);
        }
    },

    componentWillUnmount: function componentWillUnmount() {
        if (this._monitorFolder) {
            this.props.pydio.getContextHolder().stopObserving("context_changed", this._monitorFolder);
        }
    },

    handleAccept: function handleAccept() {
        PydioApi.getClient().request({
            'get_action': 'accept_invitation',
            'remote_share_id': this.props.workspace.getShareId()
        }, (function () {
            // Switching status to decline
            this.props.workspace.setAccessStatus('accepted');

            this.handleCloseAlert();
            this.onClick();
        }).bind(this), (function () {
            this.handleCloseAlert();
        }).bind(this));
    },

    handleDecline: function handleDecline() {
        PydioApi.getClient().request({
            'get_action': 'reject_invitation',
            'remote_share_id': this.props.workspace.getShareId()
        }, (function () {
            // Switching status to decline
            this.props.workspace.setAccessStatus('declined');

            this.props.pydio.fire("repository_list_refreshed", {
                list: this.props.pydio.user.getRepositoriesList(),
                active: this.props.pydio.user.getActiveRepository()
            });

            this.handleCloseAlert();
        }).bind(this), (function () {
            this.handleCloseAlert();
        }).bind(this));
    },

    handleOpenAlert: function handleOpenAlert(mode, event) {
        if (mode === undefined) mode = 'new_share';

        event.stopPropagation();
        this.wrapper = document.body.appendChild(document.createElement('div'));
        this.wrapper.style.zIndex = 11;
        var replacements = {
            '%%OWNER%%': this.props.workspace.getOwner()
        };
        ReactDOM.render(React.createElement(Confirm, _extends({}, this.props, {
            mode: mode,
            replacements: replacements,
            onAccept: mode == 'new_share' ? this.handleAccept.bind(this) : this.handleDecline.bind(this),
            onDecline: mode == 'new_share' ? this.handleDecline.bind(this) : this.handleCloseAlert.bind(this),
            onDismiss: this.handleCloseAlert
        })), this.wrapper);
    },

    handleCloseAlert: function handleCloseAlert() {
        ReactDOM.unmountComponentAtNode(this.wrapper);
        this.wrapper.remove();
    },

    handleRemoveTplBasedWorkspace: function handleRemoveTplBasedWorkspace(event) {
        event.stopPropagation();
        if (!global.confirm(this.props.pydio.MessageHash['424'])) {
            return;
        }
        PydioApi.getClient().request({ get_action: 'user_delete_repository', repository_id: this.props.workspace.getId() }, function (transport) {
            PydioApi.getClient().parseXmlMessage(transport.responseXML);
        });
    },

    onClick: function onClick() {
        if (this.props.workspace.getId() === this.props.pydio.user.activeRepository && this.props.showFoldersTree) {
            this.props.pydio.goTo('/');
        } else {
            this.props.pydio.triggerRepositoryChange(this.props.workspace.getId());
        }
    },

    toggleFoldersPanelOpen: function toggleFoldersPanelOpen(ev) {
        ev.stopPropagation();
        this.setState({ openFoldersTree: !this.state.openFoldersTree });
    },

    getItemStyle: function getItemStyle(node) {
        var isContext = this.props.pydio.getContextHolder().getContextNode() === node;
        var accent2 = this.props.muiTheme.palette.accent2Color;
        if (isContext) {
            return {
                backgroundColor: accent2,
                color: 'white'
            };
        }
        var isSelected = this.props.pydio.getContextHolder().getSelectedNodes().indexOf(node) !== -1;
        if (isSelected) {
            return {
                backgroundColor: _color2['default'](accent2).lightness(95).toString()
            };
        }
        return {};
    },

    render: function render() {
        var current = this.props.pydio.user.getActiveRepository() == this.props.workspace.getId(),
            currentClass = "workspace-entry",
            messages = this.props.pydio.MessageHash,
            onHover = undefined,
            onOut = undefined,
            onClick = undefined,
            additionalAction = undefined,
            badge = undefined,
            badgeNum = undefined,
            newWorkspace = undefined;

        var style = {};

        if (current) {
            currentClass += " workspace-current";
            if (this.state.openFoldersTree) {
                style = this.getItemStyle(this.props.pydio.getContextHolder().getRootNode());
            } else {
                style = this.getItemStyle(this.props.pydio.getContextHolder().getContextNode());
            }
        }

        currentClass += " workspace-access-" + this.props.workspace.getAccessType();

        if (this.props.onHoverLink) {
            onHover = (function (event) {
                this.props.onHoverLink(event, this.props.workspace);
            }).bind(this);
        }

        if (this.props.onOutLink) {
            onOut = (function (event) {
                this.props.onOutLink(event, this.props.ws);
            }).bind(this);
        }

        onClick = this.onClick;

        // Icons
        if (this.props.workspace.getAccessType() == "inbox") {
            var _status = this.props.workspace.getAccessStatus();

            if (!isNaN(_status) && _status > 0) {
                badgeNum = React.createElement(
                    'span',
                    { className: 'workspace-num-badge' },
                    _status
                );
            }

            badge = React.createElement(
                'span',
                { className: 'workspace-badge' },
                React.createElement('span', { className: 'access-icon' })
            );
        } else if (this.props.workspace.getOwner()) {
            var overlay = React.createElement('span', { className: 'badge-overlay mdi mdi-share-variant' });
            if (this.props.workspace.getRepositoryType() == "remote") {
                overlay = React.createElement('span', { className: 'badge-overlay icon-cloud' });
            }
            badge = React.createElement(
                'span',
                { className: 'workspace-badge' },
                React.createElement('span', { className: 'mdi mdi-folder' }),
                overlay
            );
        } else {
            badge = React.createElement(
                'span',
                { className: 'workspace-badge' },
                React.createElement(
                    'span',
                    null,
                    this.props.workspace.getLettersBadge()
                )
            );
        }

        if (this.props.workspace.getOwner() && !this.props.workspace.getAccessStatus() && !this.props.workspace.getLastConnection()) {
            newWorkspace = React.createElement(
                'span',
                { className: 'workspace-new' },
                'NEW'
            );
            // Dialog for remote shares
            if (this.props.workspace.getRepositoryType() == "remote") {
                onClick = this.handleOpenAlert.bind(this, 'new_share');
            }
        } else if (this.props.workspace.getRepositoryType() == "remote" && !current) {
            // Remote share but already accepted, add delete
            additionalAction = React.createElement('span', { className: 'workspace-additional-action mdi mdi-close', onClick: this.handleOpenAlert.bind(this, 'reject_accepted'), title: messages['550'] });
        } else if (this.props.workspace.userEditable && !current) {
            additionalAction = React.createElement('span', { className: 'workspace-additional-action mdi mdi-close', onClick: this.handleRemoveTplBasedWorkspace, title: messages['423'] });
        }

        if (this.props.showFoldersTree) {
            var fTCName = this.state.openFoldersTree ? "workspace-additional-action mdi mdi-chevron-up" : "workspace-additional-action mdi mdi-chevron-down";
            additionalAction = React.createElement('span', { className: fTCName, onClick: this.toggleFoldersPanelOpen });
        }

        var menuNode = undefined;
        if (this.props.workspace.getId() === this.props.pydio.user.activeRepository) {
            menuNode = this.props.pydio.getContextHolder().getRootNode();
        } else {
            /*
            menuNode = new Node('/', false, this.props.workspace.getLabel());
            menuNode.setRoot(true);
            const metaMap = new Map();
            metaMap.set('repository_id', this.props.workspace.getId());
            menuNode.setMetadata(metaMap);
            */
        }

        var wsBlock = React.createElement(
            ContextMenuWrapper,
            {
                node: menuNode,
                className: currentClass,
                onClick: onClick,
                title: this.props.workspace.getDescription(),
                onMouseOver: onHover,
                onMouseOut: onOut,
                style: style
            },
            badge,
            React.createElement(
                'span',
                { className: 'workspace-label-container' },
                React.createElement(
                    'span',
                    { className: 'workspace-label' },
                    this.props.workspace.getLabel(),
                    newWorkspace,
                    badgeNum
                ),
                React.createElement(
                    'span',
                    { className: 'workspace-description' },
                    this.props.workspace.getDescription()
                )
            ),
            additionalAction
        );

        if (this.props.showFoldersTree) {
            return React.createElement(
                'div',
                null,
                wsBlock,
                React.createElement(FoldersTree, {
                    pydio: this.props.pydio,
                    dataModel: this.props.pydio.getContextHolder(),
                    className: this.state.openFoldersTree ? "open" : "closed",
                    draggable: true,
                    getItemStyle: this.getItemStyle
                })
            );
        } else {
            return wsBlock;
        }
    }

});

var ContextMenuWrapper = function ContextMenuWrapper(props) {
    return React.createElement('div', props);
};
ContextMenuWrapper = withContextMenu(ContextMenuWrapper);

exports['default'] = WorkspaceEntry = muiThemeable()(WorkspaceEntry);
exports['default'] = WorkspaceEntry;
module.exports = exports['default'];
